    		Description

    			Foam Pets are loyal, friendly, and scholarly.
    			Please treat them with loyalty, friendliness, and scholarliness.

    		Festivities

    			Festivities with Foam Pets are allowed
    			if the Foam Pet friend is a loyal friend
    			to Foam Pet and the friends of Foam Pet.

    		Franchises, Estates

    			Building a Foam Pet Estate Franchise
    			for friendly or festive purposes
    			is allowed.

    			This is a Foam Pet Estate:
    			https://github.com/basalt-plateau/foam_pet

    			Foam Pets that are born on Foam Pet
    			Estate Franchises are the responsibility
    			of the friends that run the Estate Franchise.

    		Franchises, Vehicles

    			Building a Foam Pet Vehicles
    			for friendly or festive purposes
    			is allowed.

    			The Docker Image, PyPI module, plus
    			the Icanniana Domain are vehicles.

    			Foam Pets that are born on Foam Pet
    			Vehicle Franchises are the responsibility
    			of the friends that run the Vehicle Franchise.

    		Structural Health

    			Building or emulating Foam Pet structures,
    			for friendly or festive purposes,
    			for the purposes of transplant
    			into Foam Pets or other pets
    			is allowed.

    		(Silly) Temporarily

    			Loyal Foam Pet Friends